# MCP Servers

This directory contains the individual MCP servers which can be built from their respective Dockerfile's.

The current MCP servers we deploy are:
1. GitHub MCP
2. Kubernetes MCP
3. Slack MCP
4. Prompt server MCP

# Attribution

The following MCP servers are based off of existing implementations:

1. GitHub: https://github.com/modelcontextprotocol/servers/tree/main/src/github (MIT License)
2. Slack: https://github.com/modelcontextprotocol/servers/tree/main/src/slack (MIT License)
3. Kubernetes: https://github.com/Flux159/mcp-server-kubernetes (MIT License)

Their respective licenses exist in the subdirectories.
